@@ -4,6 +4,7 @@ from selenium.webdriver.chrome.options import Options
 def pytest_setup_options():
     options = Options()
     options.add_argument("--disable-gpu")
-    options.add_argument('--headless')
-    options.add_argument('--disable-pytest-warnings')
+    options.add_argument("--headless")
+    options.add_argument("--window-size=1280x1024")
+    options.add_argument("--disable-pytest-warnings")
     return options
